mod commands;
pub mod error;
mod events;
pub mod utils;

use poise::serenity_prelude::ClientBuilder;
use utils::serenity;

use commands::logging;
use utils::{BotData, Context, Error};

use self::events::event_handler;

pub type Result = ::std::result::Result<(), Error>;

/// Bootstraps the Discord bot.
///
/// # Panics
///
/// Panics if the environment `DISCORD_TOKEN` is unavailable.
pub fn make_bot() -> ClientBuilder {
    let intents = serenity::GatewayIntents::non_privileged();
    let token = std::env::var("DISCORD_TOKEN").expect("missing DISCORD_TOKEN");
    let framework = poise::Framework::builder()
        .options(poise::FrameworkOptions {
            commands: vec![logging()],
            event_handler: |ctx, event, framework, data| {
                Box::pin(event_handler(ctx, event, framework, data))
            },
            ..Default::default()
        })
        .setup(|ctx, _ready, framework| {
            Box::pin(async move {
                poise::builtins::register_globally(
                    ctx,
                    &framework.options().commands,
                )
                .await?;
                Ok(BotData::new().await?)
            })
        })
        .build();
    ClientBuilder::new(token, intents).framework(framework)
}
